==> apache-calcite-1.35.0-src.tar.gz: apache-calcite-1.35.0-src/core/src/main/java/org/apache/calcite/sql/validate/SqlIdentifierMoniker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.sql.validate;

import org.apache.calcite.sql.SqlIdentifier;

import java.util.List;
import java.util.Objects;

/**
 * An implementation of {@link SqlMoniker} that encapsulates the normalized name
 * information of a {@link SqlIdentifier}.
 */
public class SqlIdentifierMoniker implements SqlMoniker {
  //~ Instance fields --------------------------------------------------------

  private final SqlIdentifier id;

  //~ Constructors -----------------------------------------------------------

  /**
   * Creates an SqlIdentifierMoniker.
   */
  public SqlIdentifierMoniker(SqlIdentifier id) {
    this.id = Objects.requireNonNull(id, "id");
  }

  //~ Methods ----------------------------------------------------------------

  @Override public SqlMonikerType getType() {
    return SqlMonikerType.COLUMN;
  }

  @Override public List<String> getFullyQualifiedNames() {
    return id.names;
  }

  @Override public SqlIdentifier toIdentifier() {
    return id;
  }

  @Override public String toString() {
    return id.toString();
  }

  @Override public String id() {
    return id.toString();
  }
}

==> apache-calcite-1.40.0-src.tar.gz: apache-calcite-1.40.0-src/core/src/main/java/org/apache/calcite/sql/validate/SqlIdentifierMoniker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.sql.validate;

import org.apache.calcite.sql.SqlIdentifier;

import java.util.List;

import static java.util.Objects.requireNonNull;

/**
 * An implementation of {@link SqlMoniker} that encapsulates the normalized name
 * information of a {@link SqlIdentifier}.
 */
public class SqlIdentifierMoniker implements SqlMoniker {
  //~ Instance fields --------------------------------------------------------

  private final SqlIdentifier id;

  //~ Constructors -----------------------------------------------------------

  /**
   * Creates an SqlIdentifierMoniker.
   */
  public SqlIdentifierMoniker(SqlIdentifier id) {
    this.id = requireNonNull(id, "id");
  }

  //~ Methods ----------------------------------------------------------------

  @Override public SqlMonikerType getType() {
    return SqlMonikerType.COLUMN;
  }

  @Override public List<String> getFullyQualifiedNames() {
    return id.names;
  }

  @Override public SqlIdentifier toIdentifier() {
    return id;
  }

  @Override public String toString() {
    return id.toString();
  }

  @Override public String id() {
    return id.toString();
  }
}
